@@ -22,120 +22,120 @@
 
 #include <sstream>
 #include <curl/curl.h>
-#include <cstdlib>
-#include <QString>
 #include <QRegExp>
-#include <QtDeclarative>
-#include <QtNetwork/QNetworkReply>
+#include <QtNetwork/QNetworkConfigurationManager>
 
 #include "settings.h"
+
 using namespace std;
 
-extern QNetworkConfigurationManager manager;
+#define DEBUG 1
+
+class LyricsDownloaderManager;
 
 class lyricsDownloader : public QObject
 {
     Q_OBJECT
+    friend class LyricsDownloaderManager;
 public:
 
-    Q_PROPERTY(QString lyrics READ getLyrics WRITE setLyrics NOTIFY lyricsChanged)
-    Q_PROPERTY(QString savedLyrics READ getSavedLyrics WRITE setSavedLyrics NOTIFY savedLyricsChanged)
-    Q_PROPERTY(bool theseLyricsSaved READ getTheseLyricsSaved NOTIFY theseLyricsSavedSignal)
-    Q_INVOKABLE virtual short perform() = 0;
+    virtual short perform(const string & a, const string & t);
     /* Do all the activities needed for the lyrics to be shown to the user
      * Return values:
      * -1 - no internet
      * 0  - OK
      * 1  - Error downloading
      * 2  - Error parsing
-     * 3  - Lyrics absent (1 & 2)
      */
-    inline void setData(const string & a, const string & t); // set artist and track
-    Q_INVOKABLE inline void setData(const QString & a, const QString & t) // for QStrings
-    {
-        artist = a.toStdString();
-        track = t.toStdString();
-        emit dataChanged();
-    }
-    Q_INVOKABLE inline void setData(const QString & str) {setData(str.split('-')); }
-    Q_INVOKABLE inline bool anyFieldEmpty() // check whether everything is filled
-    {
-        if ( artist.empty() || track.empty() ) return true;
-        else return false;
-    }
-
-    Q_INVOKABLE inline bool lyricsExistMaeLyrica() {return progSettings.contains(savedLyricsKey);}
-    Q_INVOKABLE bool lyricsExistOMP();
-    Q_INVOKABLE void saveLyricsMaeLyrica();
-    Q_INVOKABLE bool saveLyricsOMP();
-    Q_INVOKABLE inline void deleteLyricsMaeLyrica() {progSettings.remove(savedLyricsKey);}
 
 protected:
-    lyricsDownloader(const string & a, const string & t ) : artist(a), track(t)
-    {
-        connect(this, SIGNAL(dataChanged()), this, SLOT(cleanTitle()));
-        connect(this, SIGNAL(dataChanged()), this, SLOT(findSavedLyricsKey())); // recalculate the key, so that it's always up-to-date
-    }
+    //lyricsDownloader(const string & a, const string & t ) : artist(a), track(t)
+
     // settings object
-    static Settings progSettings;
     // functions
-    virtual CURLcode download() = 0;
-    virtual string toProviderCode() const = 0;
+    virtual CURLcode download(const string& a, const string& t) ;
+    virtual string toProviderCode(const string& artist, const string& track) const = 0;
     virtual bool parse() = 0;
     // overloaded for QML functions
-    inline void setData(const QStringList& list) // for a list "artist - track"
-    {
-        artist = list[0].toStdString();
-        track = list[1].toStdString();
-        emit dataChanged();
+    // data
+    static const QString rooturl; // url for this provider
+    // helper stuff for curl
+    static size_t write_data_to_var(char *ptr, size_t size, size_t nmemb, void *userdata);
+    ostringstream buff;
+    QString lyrics_qstr; // lyrics are stored here until LyricsDownloaderManager gets them
+};
 
-    }
-    // Q _PROPERTY fucntions
+///////////////////////////////////////////////////////
+
+class LyricsDownloaderManager : public QObject
+{
+    Q_OBJECT
+    Q_ENUMS(LyricsDownloaderClass)
+public:
+    Q_PROPERTY(QString lyrics READ getLyrics WRITE setLyrics NOTIFY lyricsChanged)
+    Q_PROPERTY(QString savedLyrics READ getSavedLyrics WRITE setSavedLyrics NOTIFY savedLyricsChanged)
+    Q_PROPERTY(bool theseLyricsSaved READ getTheseLyricsSaved NOTIFY theseLyricsSavedSignal)
+
+    enum LyricsDownloaderClass
+    {
+        AZLyricsDownloaderClass = 0,
+        LyricWikiDownloaderClass = 1
+    } currentClass;
+
+    LyricsDownloaderManager(LyricsDownloaderClass lyricsDownloaderName = AZLyricsDownloaderClass );
+    ~LyricsDownloaderManager();
+
+    Q_INVOKABLE void changeLyricsDownloader(LyricsDownloaderClass lyricsDownloaderName);
+
+    // functions working on data for any downloader
+    Q_INVOKABLE short perform();
+    Q_INVOKABLE inline void setData(const QString & a, const QString & t) // for QStrings
+        { artist = a.toStdString(); track = t.toStdString(); emit dataChanged(); }
+    Q_INVOKABLE inline void setData(const QString & str) {setData(str.split('-')); }
+    Q_INVOKABLE inline bool anyFieldEmpty() // check whether everything is filled
+        { if ( artist.empty() || track.empty() ) return true; else return false; }
+
+    Q_INVOKABLE inline bool lyricsExistMaeLyrica() {return progSettings.contains(savedLyricsKey);}
+    Q_INVOKABLE void saveLyricsMaeLyrica();
+    Q_INVOKABLE inline void deleteLyricsMaeLyrica() {progSettings.remove(savedLyricsKey);}
+
+    inline void setData(const string & a, const string & t) {artist = a; track = t;} // set artist and track
+protected:
+    // internal functions
+    lyricsDownloader * newDownloader(LyricsDownloaderClass & name);
+    // internal data
+    lyricsDownloader * downloader;
+    string artist, track;
+    QString lyrics;
+    static Settings progSettings;
+
+    // additional internal data
+    QString savedLyricsKey;
+    static const QString recentSearchesUrl;
+    QString cleanedTitle;
+    QString cleanQString(QString qstr); // clean for saving, as in legacy OMP lyrics
+
+    // versions of public functions for internal usage only
+    inline void setData(const QStringList& list) // for a list "artist - track"
+        { artist = list[0].toStdString(); track = list[1].toStdString(); emit dataChanged(); }
+
+private:
+    // Q _PROPERTY functions
     inline void setLyrics(QString newlyrics) {lyrics = newlyrics;}
     inline void setSavedLyrics(QString newlyrics) { progSettings.setValue(savedLyricsKey, newlyrics); emit savedLyricsChanged(newlyrics); }
     inline QString getLyrics() const {return lyrics;}
     inline QString getSavedLyrics() const {return progSettings.value(savedLyricsKey).value<QString>();}
     inline bool getTheseLyricsSaved() const {return progSettings.contains(savedLyricsKey);}
-    // data
-    QString lyrics;
-    string* lyrics_str; // at first std::string will be used, but later QString instead
-    static const QString rooturl; // url for this provider
-    string artist, track;
-    static const QString recentSearchesUrl;
-    // helper functions for curl
-    static size_t write_data_to_var(char *ptr, size_t size, size_t nmemb, void *userdata);
-private:
-    QString savedLyricsKey;
-    static const QString OMPLyricsRoot;
-    QString cleanedTitle;
-    QString cleanQString(QString qstr);
-    QString lyricsUrlOMP;
-signals:
+
+signals: // for Q_PROPERTY
     void dataChanged();
     void lyricsChanged(QString);
     void savedLyricsChanged(QString);
     void theseLyricsSavedSignal(QString);
+
 protected slots:
     void findSavedLyricsKey() {savedLyricsKey = "lyrics/" + cleanedTitle;}
     void cleanTitle();
 };
 
-class AZLyricsDownloader : public lyricsDownloader
-{
-    Q_OBJECT
-public:
-    AZLyricsDownloader() : lyricsDownloader("", "") {}
-    AZLyricsDownloader(const string & a, const string & t) : lyricsDownloader(a, t) {}
-    Q_INVOKABLE short perform();
-    //Q_INVOKABLE inline void setData(const string & a, const string & t);// set artist and track
-
-protected:
-    virtual CURLcode download();
-    virtual string toProviderCode() const;
-    virtual bool parse();
-    /**/
-    static const QString rooturl;
-    static const QRegExp startcomment, endcomment; // comments in the azlyrics.com website which indicate start and end of lyrics
-};
-
 #endif // LYRICSDOWNLOADER_H
