@@ -26,7 +26,7 @@
 
 #include "qmlapplicationviewer.h"
 #include "lyricsDownloader.h"
-#include "mainWindow.h"
+#include "AZLyricsDownloader.h"
 #include "settings.h"
 
 int main(int argc, char *argv[])
@@ -35,11 +35,11 @@ int main(int argc, char *argv[])
     QmlApplicationViewer viewer;
     // qml preparations
 
-    QNetworkConfigurationManager manager;
+    /*QNetworkConfigurationManager manager;
     QNetworkConfiguration cfg = manager.defaultConfiguration();
     QNetworkSession* session = new QNetworkSession(cfg);
     session->setSessionProperty("ConnectInBackground", true);
-    session->open();
+    session->open();*/
 
     viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
     viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
@@ -47,6 +47,7 @@ int main(int argc, char *argv[])
     qmlRegisterUncreatableType<lyricsDownloader>("MaeLyrica", 1, 0, "lyricsDownloader", "");
     qmlRegisterType<AZLyricsDownloader>("MaeLyrica", 1, 0, "AZLyricsDownloader");
     qmlRegisterType<Settings>("MaeLyrica", 1, 0, "Settings");
+    qmlRegisterType<LyricsDownloaderManager>("MaeLyrica", 1, 0, "LyricsDownloaderManager");
 
     viewer.setOrientation(QmlApplicationViewer::ScreenOrientationAuto);
     viewer.setMainQmlFile(QLatin1String("qml/maelyrica/main.qml"));
